@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008-2013 Codership Oy <info@codership.com>
  *
- * $Id: gcs.c 3217 2013-08-23 12:09:40Z alex $
+ * $Id: gcs.c 3336 2013-10-28 07:41:56Z teemu $
  */
 
 /*
@@ -1249,7 +1249,8 @@ static void *gcs_recv_thread (void *arg)
 }
 
 /* Opens connection to group */
-long gcs_open (gcs_conn_t* conn, const char* channel, const char* url)
+long gcs_open (gcs_conn_t* conn, const char* channel, const char* url,
+               bool const bootstrap)
 {
     long ret = 0;
 
@@ -1266,7 +1267,7 @@ long gcs_open (gcs_conn_t* conn, const char* channel, const char* url)
 
     if (GCS_CONN_CLOSED == conn->state) {
 
-        if (!(ret = gcs_core_open (conn->core, channel, url))) {
+        if (!(ret = gcs_core_open (conn->core, channel, url, bootstrap))) {
 
             _reset_pkt_size(conn);
 
